==> haskell-rere-0.2.0.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-G1pW26TweCXDrDkILFjoF2
key:                  rere-0.2.0.1-G1pW26TweCXDrDkILFjoF2
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  507185a54612378bf81b211505ad38ef
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-G1pW26TweCXDrDkILFjoF2
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD base-4.17.2.1
    containers-0.6.7 fin-0.3-2vuPZtAtb3ZLTYYKGkJELk parsec-3.1.16.1
    transformers-0.5.6.2 vec-0.5-KfrdvoorAr31A9gnkIrwVS

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rere-0.2.0.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.1
visibility:           public
id:                   rere-0.2.0.1-2eKUo25LWd011siCb3VdSB
key:                  rere-0.2.0.1-2eKUo25LWd011siCb3VdSB
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  c28b0b96a502d2ca227569b62d1cf8c5
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rere-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.1-2eKUo25LWd011siCb3VdSB
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD base-4.17.2.1
    containers-0.6.7 fin-0.3-2vuPZtAtb3ZLTYYKGkJELk parsec-3.1.16.1
    transformers-0.5.6.2 vec-0.5-FiBftTTwdSl7SkPXdUlCyc

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
